@@ -1,17 +1,17 @@
 #!/usr/bin/python3 -i
 #
-# Copyright (c) 2015-2024 The Khronos Group Inc.
-# Copyright (c) 2015-2024 Valve Corporation
-# Copyright (c) 2015-2024 LunarG, Inc.
-# Copyright (c) 2015-2024 Google Inc.
-# Copyright (c) 2023-2024 RasterGrid Kft.
+# Copyright (c) 2015-2025 The Khronos Group Inc.
+# Copyright (c) 2015-2025 Valve Corporation
+# Copyright (c) 2015-2025 LunarG, Inc.
+# Copyright (c) 2015-2025 Google Inc.
+# Copyright (c) 2023-2025 RasterGrid Kft.
 #
 # SPDX-License-Identifier: Apache-2.0
 
 import os
 import re
-from generators.vulkan_object import Struct, Member
-from generators.base_generator import BaseGenerator
+from vulkan_object import Struct, Member
+from base_generator import BaseGenerator
 from generators.generator_utils import PlatformGuardHelper
 
 class SafeStructOutputGenerator(BaseGenerator):
@@ -61,9 +61,11 @@ class SafeStructOutputGenerator(BaseGenerator):
             'VkDescriptorDataEXT',
             'VkIndirectCommandsTokenDataEXT',
             'VkIndirectExecutionSetInfoEXT',
+            'VkResourceDescriptorDataEXT',
         ]
         self.union_of_pointer_callers = [
             'VkDescriptorGetInfoEXT',
+            'VkResourceDescriptorInfoEXT',
         ]
 
         # Will update the the function interface
@@ -134,15 +136,21 @@ class SafeStructOutputGenerator(BaseGenerator):
         return False
 
     def generate(self):
+        # Should be fixed in 1.4.310 headers
+        # https://gitlab.khronos.org/vulkan/vulkan/-/merge_requests/7196
+        manual_protect = ["VkCudaModuleNV", "VkCudaFunctionNV", "VkCudaModuleCreateInfoNV", "VkCudaFunctionCreateInfoNV", "VkCudaLaunchInfoNV", "VkPhysicalDeviceCudaKernelLaunchFeaturesNV", "VkPhysicalDeviceCudaKernelLaunchPropertiesNV", "VkSetPresentConfigNV", "VkPhysicalDevicePresentMeteringFeaturesNV"]
+        for struct in [x for x in self.vk.structs.values() if x.name in manual_protect]:
+            struct.protect = "VK_ENABLE_BETA_EXTENSIONS"
+
         self.write(f'''// *** THIS FILE IS GENERATED - DO NOT EDIT ***
             // See {os.path.basename(__file__)} for modifications
 
             /***************************************************************************
             *
-            * Copyright (c) 2015-2024 The Khronos Group Inc.
-            * Copyright (c) 2015-2024 Valve Corporation
-            * Copyright (c) 2015-2024 LunarG, Inc.
-            * Copyright (c) 2015-2024 Google Inc.
+            * Copyright (c) 2015-2025 The Khronos Group Inc.
+            * Copyright (c) 2015-2025 Valve Corporation
+            * Copyright (c) 2015-2025 LunarG, Inc.
+            * Copyright (c) 2015-2025 Google Inc.
             *
             * SPDX-License-Identifier: Apache-2.0
             *
@@ -726,21 +734,13 @@ void FreePnextChain(const void *pNext) {
 
             safe_name = self.convertName(struct.name)
             if struct.union:
-                if struct.name in self.union_of_pointers:
-                    default_init_list = ' type_at_end {0},'
-                    out.append(f'''
-                        {safe_name}::{safe_name}(const {struct.name}* in_struct{self.custom_construct_params.get(struct.name, '')}, [[maybe_unused]] PNextCopyState* copy_state{copy_pnext_param})
-                        {{
-                        {copy_pnext + construct_txt}}}
-                        ''')
-                else:
-                    # Unions don't allow multiple members in the initialization list, so just call initialize
-                    out.append(f'''
-                        {safe_name}::{safe_name}(const {struct.name}* in_struct{self.custom_construct_params.get(struct.name, '')}, PNextCopyState*)
-                        {{
-                            initialize(in_struct);
-                        }}
-                        ''')
+                # Unions don't allow multiple members in the initialization list, so just call initialize
+                out.append(f'''
+                    {safe_name}::{safe_name}(const {struct.name}* in_struct{self.custom_construct_params.get(struct.name, '')}, PNextCopyState*)
+                    {{
+                        initialize(in_struct);
+                    }}
+                    ''')
             else:
                 out.append(f'''
                     {safe_name}::{safe_name}(const {struct.name}* in_struct{self.custom_construct_params.get(struct.name, '')}, [[maybe_unused]] PNextCopyState* copy_state{copy_pnext_param}) :{init_list}
@@ -748,7 +748,11 @@ void FreePnextChain(const void *pNext) {
                     {copy_pnext_if + construct_txt}}}
                     ''')
             if '' != default_init_list:
+                # trim trailing comma from initializer list
                 default_init_list = f' :{default_init_list[:-1]}'
+                # truncate union initializer list to first element
+                if struct.union:
+                    default_init_list = default_init_list.split(',')[0]
             default_init_body = '\n' + custom_defeault_construct_txt[struct.name] if struct.name in custom_defeault_construct_txt else ''
             out.append(f'''
                 {safe_name}::{safe_name}(){default_init_list}
